@@ -1,7 +1,7 @@
 use GD::Graph::pie;
 require 'save.pl';
 
-print STDERR "Processing sample 9-3\n";
+print STDERR "Processing sample93\n";
 
 @data = ( 
 	[ qw( 1st 2nd 3rd 4th 5th 6th 7th ) ],
@@ -16,6 +16,8 @@ $my_graph->set(
 	label => 'Foo Bar',
 	# The following should prevent the 7th slice from getting a label
 	suppress_angle => 5, 
+
+	transparent => 0,
 );
 
 $my_graph->plot(\@data);
